@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..11\n"; }
+BEGIN { $| = 1; print "1..15\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use HTML::SimpleParse;
 $loaded = 1;
@@ -44,18 +44,18 @@ sub report_result {
 # 4
 {
 	my %hash = HTML::SimpleParse->parse_args('A="xx" B c="hi" ');
-	&report_result(($hash{A} eq "xx" and exists $hash{B} and $hash{c} eq "hi"),
-	               "$hash{A} eq xx and exists $hash{B} (". exists($hash{B}). ") and $hash{c} eq hi\n");
+	&report_result(($hash{A} eq "xx" and exists $hash{B} and $hash{C} eq "hi"),
+	               "$hash{A} eq xx and exists $hash{B} (". exists($hash{B}). ") and $hash{C} eq hi\n");
 }
 
 # 5
 {
 	my $text = 'type=checkbox checked name=flavor value="chocolate or strawberry"';
 	my %hash = HTML::SimpleParse->parse_args( $text );
-	&report_result(($hash{type} eq "checkbox" and exists $hash{checked} and 
-	                $hash{value} eq "chocolate or strawberry"),
-	               "$hash{type} eq checkbox and exists (". exists($hash{checked}) .") and 
-	                $hash{value} eq 'chocolate or strawberry'");
+	&report_result(($hash{TYPE} eq "checkbox" and exists $hash{CHECKED} and 
+	                $hash{VALUE} eq "chocolate or strawberry"),
+	               "$hash{TYPE} eq checkbox and exists (". exists($hash{CHECKED}) .") and 
+	                $hash{VALUE} eq 'chocolate or strawberry'");
 }
 
 # 6
@@ -89,19 +89,19 @@ EOF
 # 8
 {
 	my %hash = HTML::SimpleParse->parse_args('a="b=c"');
-	&report_result($hash{a} eq "b=c", "hash: @{[ %hash ]}\n");
+	&report_result($hash{A} eq "b=c", "hash: @{[ %hash ]}\n");
 }
 
 # 9
 {
 	my %hash = HTML::SimpleParse->parse_args('val="a \"value\""');
-	&report_result($hash{val} eq 'a "value"', "value: $hash{val}\n");
+	&report_result($hash{VAL} eq 'a "value"', "value: $hash{VAL}\n");
 }
 
 # 10
 {
   my %hash = HTML::SimpleParse->parse_args('val = "a \"value\""');
-  &report_result($hash{val} eq 'a "value"', "value: $hash{val}\n");
+  &report_result($hash{VAL} eq 'a "value"', "value: $hash{VAL}\n");
 }
 
 # 11
@@ -113,3 +113,31 @@ EOF
   HTML::SimpleParse->new();
   &report_result($ok);
 }
+
+# 12
+{
+  my %hash = HTML::SimpleParse->parse_args("val='a value'");
+  &report_result($hash{VAL} eq 'a value', "value: $hash{VAL}\n");
+}
+
+# 13
+{
+  local $HTML::SimpleParse::FIX_CASE = 0;
+  my %hash = HTML::SimpleParse->parse_args("val='a value'");
+  &report_result($hash{val} eq 'a value', "value: $hash{val}\n");
+}
+
+# 14
+{
+  local $HTML::SimpleParse::FIX_CASE = 0;
+  my %hash = HTML::SimpleParse->parse_args("Val='a value'");
+  &report_result($hash{Val} eq 'a value', "value: $hash{Val}\n");
+}
+
+# 15
+{
+  my $p = new HTML::SimpleParse('', fix_case => 0);
+  my %hash = $p->parse_args("Val='a value'");
+  &report_result($hash{Val} eq 'a value', "value: $hash{Val}\n");
+}
+
